OC.L10N.register(
    "lib",
    {
    "Help" : "උදව්",
    "Personal" : "පෞද්ගලික",
    "Users" : "පරිශීලකයන්",
    "Admin" : "පරිපාලක",
    "today" : "අද",
    "yesterday" : "ඊයේ",
    "last month" : "පෙර මාසයේ",
    "last year" : "පෙර අවුරුද්දේ",
    "seconds ago" : "තත්පරයන්ට පෙර",
    "web services under your control" : "ඔබට පාලනය කළ හැකි වෙබ් සේවාවන්",
    "Application is not enabled" : "යෙදුම සක්‍රිය කර නොමැත",
    "Authentication error" : "සත්‍යාපන දෝෂයක්",
    "Token expired. Please reload page." : "ටෝකනය කල් ඉකුත් වී ඇත. පිටුව නැවුම් කරන්න",
    "Apps" : "යෙදුම්"
},
"nplurals=2; plural=(n != 1);");
